@@ -92,6 +92,9 @@ mediaShow.buttonNextContent = "&rarr;";
 
 //Override slideshow behaviour
 //Show the next slide in the given slideshow
+onSlodeshowSkipNext = null;
+onSlodeshowSkipPrev = null;
+
 mediaShow.next = function (slideshowIndex)
 {
   var slideshow = mediaShow.slideshows[slideshowIndex];
@@ -101,7 +104,7 @@ mediaShow.next = function (slideshowIndex)
   }
   else
   {
-    Arnolfini.getNextEvent()
+    Arnolfini.getNextEvent(slideshow)
   }
   
   return false;
@@ -117,7 +120,7 @@ mediaShow.prev = function (slideshowIndex)
   }
   else
   {
-    Arnolfini.getPrevEvent()
+    Arnolfini.getPrevEvent(slideshow)
   }
   
   return false;
@@ -154,21 +157,28 @@ mediaShow.readURLAndUpdate = function ()
   });
 };
 
-Arnolfini.getNextEvent = function ()
+Arnolfini.getNextEvent = function (slideshow)
 {
 	if (onSlodeshowSkipNext !== null)
 	{
 		window.location = onSlodeshowSkipNext;
 	}
-	
+	else
+	{
+		mediaShow.goToSlide(0, slideshow);
+	}
 }
 
-Arnolfini.getPrevEvent = function ()
+Arnolfini.getPrevEvent = function (slideshow)
 {
-	if (onSlodeshowSkipPrev!== null)
+	if (onSlodeshowSkipPrev !== null)
 	{
 		window.location = onSlodeshowSkipPrev + "#lastpic";
 	}
+	else
+	{
+		mediaShow.goToSlide(slideshow.size-1, slideshow);
+	}
 }
 
 $(document).ready(function() {
